@@ -490,13 +490,16 @@ class IrcBot(object):
         return self.server_channels
 
     async def list_names(self, channel):
-        """Lists users nicks in channel. Also check bot.channel_names.
+        """Lists users nicks in channel. 
+        Also check bot.channel_names for a non sanitized version(like starting with @ for operators, if you want to detect them)
 
         :param channel:str channel name
         """
         await self._send_data(f"NAMES {channel}")
         await self.sleep(1)
-        return self.channel_names
+        names = self.channel_names[channel]
+        names = [name[1:] if name.startswith("@") else name for name in names]
+        return names
 
     async def send_message(self, message, channel=None):
         """Sends a text message. The message will be enqueued and sent whenever the messaging loop arrives on it.
@@ -771,6 +774,8 @@ class IrcBot(object):
 
                 channel = message['channel']
                 sender_nick = message['nick']
+                if sender_nick.startswith("@"):
+                    sender_nick = sender_nick[1:]
                 debug("sent by:", sender_nick)
                 splitter = "PRIVMSG " + channel + " :"
                 msg = splitter.join(data.split(splitter)[1:]).strip()
